@@ -12,7 +12,9 @@
 #include <QString>
 
 #include "backends/devicelink.h"
+#include "deviceinfo.h"
 #include "networkpacket.h"
+#include "pairstate.h"
 
 class DeviceLink;
 class KdeConnectPlugin;
@@ -21,25 +23,19 @@ class KDECONNECTCORE_EXPORT Device : public QObject
 {
     Q_OBJECT
     Q_CLASSINFO("D-Bus Interface", "org.kde.kdeconnect.device")
-    Q_PROPERTY(QString type READ type NOTIFY typeChanged)
+    Q_PROPERTY(QString type READ typeAsString NOTIFY typeChanged)
     Q_PROPERTY(QString name READ name NOTIFY nameChanged)
     Q_PROPERTY(QString iconName READ iconName CONSTANT)
+    Q_PROPERTY(QString verificationKey READ verificationKey CONSTANT)
     Q_PROPERTY(QString statusIconName READ statusIconName NOTIFY statusIconNameChanged)
     Q_PROPERTY(bool isReachable READ isReachable NOTIFY reachableChanged)
-    Q_PROPERTY(bool isTrusted READ isTrusted NOTIFY trustedChanged)
+    Q_PROPERTY(bool isPaired READ isPaired NOTIFY pairStateChanged)
+    Q_PROPERTY(bool isPairRequested READ isPairRequested NOTIFY pairStateChanged)
+    Q_PROPERTY(bool isPairRequestedByPeer READ isPairRequestedByPeer NOTIFY pairStateChanged)
+    Q_PROPERTY(int pairState READ pairStateAsInt NOTIFY pairStateChanged)
     Q_PROPERTY(QStringList supportedPlugins READ supportedPlugins NOTIFY pluginsChanged)
-    Q_PROPERTY(bool hasPairingRequests READ hasPairingRequests NOTIFY hasPairingRequestsChanged)
 
 public:
-    enum DeviceType {
-        Unknown,
-        Desktop,
-        Laptop,
-        Phone,
-        Tablet,
-        Tv,
-    };
-
     /**
      * Restores the @p device from the saved configuration
      *
@@ -52,7 +48,7 @@ public:
      *
      * We know everything but we don't trust it yet
      */
-    Device(QObject *parent, const NetworkPacket &np, DeviceLink *dl);
+    Device(QObject *parent, DeviceLink *link);
 
     ~Device() override;
 
@@ -62,19 +58,27 @@ public:
     {
         return QStringLiteral("/modules/kdeconnect/devices/") + id();
     }
-    QString type() const;
+    DeviceType type() const;
+    QString typeAsString() const
+    {
+        return type().toString();
+    };
     QString iconName() const;
     QString statusIconName() const;
-    Q_SCRIPTABLE QByteArray verificationKey() const;
+    Q_SCRIPTABLE QString verificationKey() const;
     Q_SCRIPTABLE QString encryptionInfo() const;
 
     // Add and remove links
-    void addLink(const NetworkPacket &identityPacket, DeviceLink *);
-    void removeLink(DeviceLink *);
+    void addLink(DeviceLink *link);
+    void removeLink(DeviceLink *link);
 
-    Q_SCRIPTABLE bool isTrusted() const;
+    bool updateDeviceInfo(const DeviceInfo &deviceInfo);
 
-    Q_SCRIPTABLE QStringList availableLinks() const;
+    PairState pairState() const;
+    Q_SCRIPTABLE int pairStateAsInt() const; // Hack because qdbus doesn't like enums
+    Q_SCRIPTABLE bool isPaired() const;
+    Q_SCRIPTABLE bool isPairRequested() const;
+    Q_SCRIPTABLE bool isPairRequestedByPeer() const;
     virtual bool isReachable() const;
 
     Q_SCRIPTABLE QStringList loadedPlugins() const;
@@ -86,8 +90,6 @@ public:
     Q_SCRIPTABLE void setPluginEnabled(const QString &pluginName, bool enabled);
     Q_SCRIPTABLE bool isPluginEnabled(const QString &pluginName) const;
 
-    void cleanUnneededLinks();
-
     int protocolVersion();
     QStringList supportedPlugins() const;
 
@@ -100,40 +102,33 @@ public Q_SLOTS:
 
     // Dbus operations
 public Q_SLOTS:
-    Q_SCRIPTABLE void requestPair(); // to all links
-    Q_SCRIPTABLE void unpair(); // from all links
+    Q_SCRIPTABLE void requestPairing();
+    Q_SCRIPTABLE void unpair();
     Q_SCRIPTABLE void reloadPlugins(); // from kconf
 
     Q_SCRIPTABLE void acceptPairing();
-    Q_SCRIPTABLE void rejectPairing();
-    Q_SCRIPTABLE bool hasPairingRequests() const;
+    Q_SCRIPTABLE void cancelPairing();
 
     Q_SCRIPTABLE QString pluginIconName(const QString &pluginName);
 private Q_SLOTS:
     void privateReceivedPacket(const NetworkPacket &np);
     void linkDestroyed(QObject *o);
-    void pairStatusChanged(DeviceLink::PairStatus current);
-    void addPairingRequest(PairingHandler *handler);
-    void removePairingRequest(PairingHandler *handler);
+
+    void pairingHandler_incomingPairRequest();
+    void pairingHandler_pairingFailed(const QString &errorMessage);
+    void pairingHandler_pairingSuccessful();
+    void pairingHandler_unpaired();
 
 Q_SIGNALS:
     Q_SCRIPTABLE void pluginsChanged();
     Q_SCRIPTABLE void reachableChanged(bool reachable);
-    Q_SCRIPTABLE void trustedChanged(bool trusted);
-    Q_SCRIPTABLE void pairingError(const QString &error);
+    Q_SCRIPTABLE void pairStateChanged(int pairState); // Hack because qdbus doesn't like enums
+    Q_SCRIPTABLE void pairingFailed(const QString &error);
     Q_SCRIPTABLE void nameChanged(const QString &name);
     Q_SCRIPTABLE void typeChanged(const QString &type);
     Q_SCRIPTABLE void statusIconNameChanged();
 
-    Q_SCRIPTABLE void hasPairingRequestsChanged(bool hasPairingRequests);
-
 private: // Methods
-    static DeviceType str2type(const QString &deviceType);
-    static QString type2str(DeviceType deviceType);
-
-    void setName(const QString &name);
-    void setType(const QString &strtype);
-    QString iconForStatus(bool reachable, bool paired) const;
     QSslCertificate certificate() const;
 
 private:
