@@ -4,17 +4,16 @@
  * SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
  */
 
-#ifndef SYSTEMVOLUMEPLUGINWIN_H
-#define SYSTEMVOLUMEPLUGINWIN_H
+#pragma once
 
-#include <QObject>
 #include <QMap>
+#include <QObject>
 
 #include <core/kdeconnectplugin.h>
 
 #include <Windows.h>
-#include <mmdeviceapi.h>
 #include <endpointvolume.h>
+#include <mmdeviceapi.h>
 
 #ifdef __MINGW32__
 #include <initguid.h>
@@ -23,28 +22,26 @@
 #define PACKET_TYPE_SYSTEMVOLUME QStringLiteral("kdeconnect.systemvolume")
 #define PACKET_TYPE_SYSTEMVOLUME_REQUEST QStringLiteral("kdeconnect.systemvolume.request")
 
-class Q_DECL_EXPORT SystemvolumePlugin : public KdeConnectPlugin
+class SystemvolumePlugin : public KdeConnectPlugin
 {
     Q_OBJECT
 
-  public:
+public:
     explicit SystemvolumePlugin(QObject *parent, const QVariantList &args);
     ~SystemvolumePlugin();
-    bool receivePacket(const NetworkPacket& np) override;
+    void receivePacket(const NetworkPacket &np) override;
     void connected() override;
 
-  private:
+private:
     class CMMNotificationClient;
     class CAudioEndpointVolumeCallback;
 
     bool valid;
-    IMMDeviceEnumerator* deviceEnumerator;
-    CMMNotificationClient* deviceCallback;
+    IMMDeviceEnumerator *deviceEnumerator;
+    CMMNotificationClient *deviceCallback;
     QMap<QString, QPair<IAudioEndpointVolume *, CAudioEndpointVolumeCallback *>> sinkList;
     QMap<QString, QString> idToNameMap;
 
     bool sendSinkList();
-    HRESULT setDefaultAudioPlaybackDevice(QString& name, bool enabled);
+    HRESULT setDefaultAudioPlaybackDevice(QString &name, bool enabled);
 };
-
-#endif // SYSTEMVOLUMEPLUGINWIN_H
